
import click
import os
from PIL import Image, ImageFilter


@click.command(
        help="Adds background to any transparent image"
        )
@click.option(
        '-i', 
        '--inputimage', 
        type=click.Path(),
        default="./main.png",
        show_default=True,
        help="Front Image"
        )
@click.option(
        '-o', 
        '--outputimage', 
        type=click.Path(),
        default="./main_resized.png",
        show_default=True,
        help="Resized output image"
        )
@click.option(
        '-r',
        '--radius',
        type=click.INT,
        default=2,
        show_default=True,
        help='Radius of GaussianBlur'
        )
@click.option(
        '-t',
        '--opacity',
        type=click.FLOAT,
        default=1,
        show_default=True,
        help="Opacity of bluredimage"
        )
def blur(inputimage, outputimage, radius, opacity):
    inputimage = Image.open(inputimage)
    bluredimage = inputimage.filter(ImageFilter.GaussianBlur(radius))

    datas = bluredimage.getdata()
    newData = []
    for item in datas:
        newData.append((item[0], item[1], item[2], int(opacity*item[3])))

    bluredimage.putdata(newData)
    
    bluredimage.save(outputimage, format="png")
    click.echo(f'{inputimage} is blured to radius {radius} as {outputimage}.')











import click


#from .resize import resize
#from .info import info
from .removebg import removebg
from .pixelate import pixelate
from .blur import blur
from .stack import stack
from .render import render
from .layer import layer


CONTEXT_SETTINGS = dict(
        help_option_names = [
            '-h',
            '--help'
        ]
)

@click.group(context_settings=CONTEXT_SETTINGS)
def main():
    pass


main.add_command(layer)
main.add_command(render)
main.add_command(stack)
main.add_command(blur)
main.add_command(pixelate)
main.add_command(removebg)
#main.add_command(resize)
#main.add_command(info)




import click
import os
from PIL import Image


def crommakey(value:int, tolerance:int, match_value:int)->bool:
	if (value-tolerance) >= 0:
		l_value = value - tolerance
	else:
		l_value = 0

	if (value+tolerance) <= 255:
		u_value = value + tolerance
	else:
		u_value = 255

	if match_value <= u_value and match_value >= l_value:
		return True
	else:
		return False


@click.command(
        help="Adds background to any transparent image"
        )
@click.option(
        '-i', 
        '--inputimage', 
        type=click.Path(),
        default="./main.png",
        show_default=True,
        help="Front Image"
        )
@click.option(
        '-o', 
        '--outputimage', 
        type=click.Path(),
        default="./main_removedbg.png",
        show_default=True,
        help="Resized output image"
        )
@click.option(
		'-c',
		'--color',
		type=click.Tuple([int, int, int]),
		default=(255, 255, 255),
		show_default=True,
		help="Color to be removed"
		)
@click.option(
		'-t',
		'--tolerance',
		type=click.INT,
		default=10,
		show_default=True,
		help="Tolerence: amount of color variation for croomakey."
		)
def removebg(inputimage, outputimage, color, tolerance):
	inputimage = Image.open(inputimage)
	img = inputimage.convert("RGBA")
	datas = img.getdata()
	newData = []

	for item in datas:
		if crommakey(color[0], tolerance, item[0]) and crommakey(color[1], tolerance, item[1]) and crommakey(color[2], tolerance, item[2]):
			newData.append((255, 255, 255, 0))
		else:
			newData.append(item)

	img.putdata(newData)
	img.save(outputimage, "PNG")
	click.echo(f'{inputimage} is processed as {outputimage}.')








from PIL import Image


import click

@click.command(
        help="Pixelates any image."
        )
@click.option(
        '-i',
        '--inputfile',
        type=click.Path(),
        default="./main.png",
        show_default=True,
        help="Input file"
        )
@click.option(
        '-o',
        '--outputfile',
        type=click.Path(),
        default="./pixelated.png",
        show_default=True,
        help="Output file"
        )
@click.option(
        '-p',
        '--pixels',
        type=click.Tuple([int, int]),
        default=(16, 16),
        show_default=True,
        help="Pixelating size"
        )
def pixelate(inputfile, outputfile, pixels):
    image = Image.open(inputfile)
    p_image = image.resize(pixels, resample=Image.Resampling.BILINEAR)

    p_image.resize(image.size, Image.Resampling.NEAREST).save(outputfile, 'PNG')




import click
import os
from PIL import Image, ImageFilter


@click.command(
        help="Creates an image using given size and color."
        )
@click.option(
        '-s', 
        '--size', 
        type=click.Tuple([int, int]),
        default=(1600, 1600),
        show_default=True,
        help="Size of image:(width, height)"
        )
@click.option(
        '-o', 
        '--outputimage', 
        type=click.Path(),
        default="./background.png",
        show_default=True,
        help="Resized output image"
        )
@click.option(
        '-r',
        '--radius',
        type=click.INT,
        default=2,
        show_default=True,
        help='Radius of GaussianBlur'
        )
@click.option(
        '-t',
        '--opacity',
        type=click.FLOAT,
        default=1,
        show_default=True,
        help="Opacity of bluredimage"
        )
@click.option(
        '-c',
        '--color',
        type=click.Tuple([int, int, int]),
        default=(255, 0, 0),
        show_default=True,
        help='COlor of the image'
        )
def render(size, outputimage, radius, opacity, color):
    inputimage = Image.new('RGBA', size)
    #bluredimage = inputimage.filter(ImageFilter.GaussianBlur(radius))

    datas = inputimage.getdata()
    newData = []
    for item in datas:
        newData.append((color[0], color[1], color[2], int(opacity*255)))

    inputimage.putdata(newData)

    inputimage.save(outputimage, format="png")
    click.secho(f'\tImage of size {size}, color {color} rendered -> {os.path.basename(outputimage)}', fg='bright_red')












import click
import os
from PIL import Image


def crommakey(value:int, tolerance:int, match_value:int)->bool:
	if (value-tolerance) >= 0:
		l_value = value - tolerance
	else:
		l_value = 0

	if (value+tolerance) <= 255:
		u_value = value + tolerance
	else:
		u_value = 255

	if match_value <= u_value and match_value >= l_value:
		return True
	else:
		return False


@click.command(
        help="Replaces any color with other color."
        )
@click.option(
        '-i', 
        '--inputimage', 
        type=click.Path(),
        default="./main.png",
        show_default=True,
        help="Front Image"
        )
@click.option(
        '-o', 
        '--outputimage', 
        type=click.Path(),
        default="./main_removedbg.png",
        show_default=True,
        help="Resized output image"
        )
@click.option(
		'-c',
		'--color',
		type=click.Tuple([int, int, int]),
		default=(255, 255, 255),
		show_default=True,
		help="Color to be removed"
		)
@click.option(
		'-t',
		'--opacity',
		type=click.FLOAT,
		default=1,
		show_default=True,
		help="Opacity of the color"
		)
def layer(inputimage, outputimage, color, opacity):
    
    inputfile = os.path.basename(inputimage)
    outputfile = os.path.basename(outputimage)

    inputimage = Image.open(inputimage)
    img = inputimage.convert("RGBA")
    datas = img.getdata()

    newData = []

    for item in datas:
        if item[3] != 0:
            newData.append((color[0], color[1], color[2], item[3]))
        else:
            newData.append(item)

    img.putdata(newData)
    img.save(outputimage, "PNG")
    click.secho(f'\t{inputfile} is processed as {outputfile}', fg='bright_green')









import click
import os
from PIL import Image



@click.command(
        help="Adds background to any transparent image"
        )
@click.option(
        '-i', 
        '--inputimage', 
        type=click.Path(),
        default="./main.png",
        show_default=True,
        help="Front Image"
        )
@click.option(
        '-o', 
        '--outputimage', 
        type=click.Path(),
        default="./main_resized.png",
        show_default=True,
        help="Resized output image"
        )
@click.option(
        '-s',
        '--size',
        type=click.Tuple([int, int]),
        default=(1600, 1600),
        show_default=True,
        help='Size of outputimage.'
        )
def resize(inputimage, outputimage, size):
    inputimage = Image.open(inputimage)
    outputimage = inputimage.resize((size[0], size[1]))
#    width = (background.width - frontImage.width) // 2
#    height = (background.height - frontImage.height) // 2
#    background.paste(frontImage, (width, height), frontImage)
    outputimage.save(outputimage, format="png")

    click.echo(f'{inputimage} is resized to {size} as {outputimage}.')

#    with click.progressbar([1, 2, 3]) as bar:
#        for x in bar:
#            print(f"sleep({x})...")
#            time.sleep(x)







